package com.ruoyi.system.domain.dto;

import java.time.LocalDate;

public class SysIncomeDto {

    private Long tIncome;
    private Long tRefund;
    private LocalDate date;

    public Long gettIncome() {
        return tIncome;
    }

    public void settIncome(Long tIncome) {
        this.tIncome = tIncome;
    }

    public LocalDate getDate() {
        return date;
    }

    public void setDate(LocalDate date) {
        this.date = date;
    }

    public Long gettRefund() {
        return tRefund;
    }

    public void settRefund(Long tRefund) {
        this.tRefund = tRefund;
    }

}
